@@ -8,6 +8,7 @@ from cognite.transformations_cli.commands.deploy.transformation_types import (
     DestinationConfig,
     DestinationType,
     QueryConfig,
+    RawDestinationConfig,
     ReadWriteAuthentication,
     TransformationConfig,
     TransformationConfigError,
@@ -72,9 +73,11 @@ class DestinationLegacy:
     raw_database: Optional[str] = None
     raw_table: Optional[str] = None
 
-    def to_new(self) -> DestinationConfig:
+    def to_new(self) -> Union[RawDestinationConfig, DestinationConfig]:
         new_type = legacy_destination_type_to_new(self.type)
-        return DestinationConfig(new_type, self.raw_database, self.raw_table)
+        if self.raw_database and self.raw_table:
+            return RawDestinationConfig(raw_database=self.raw_database, raw_table=self.raw_table)
+        return DestinationConfig(new_type)
 
 
 @dataclass
